@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/backend/utils/adt/varlena.c,v 1.106 2003/09/25 06:58:05 petere Exp $
+ *	  $Header: /cvsroot/pgsql/src/backend/utils/adt/varlena.c,v 1.106.2.6 2006/05/21 20:06:43 tgl Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -16,17 +16,18 @@
 
 #include <ctype.h>
 
-#include "mb/pg_wchar.h"
-#include "miscadmin.h"
 #include "access/tuptoaster.h"
 #include "catalog/pg_type.h"
 #include "lib/stringinfo.h"
 #include "libpq/crypt.h"
 #include "libpq/pqformat.h"
+#include "mb/pg_wchar.h"
+#include "miscadmin.h"
+#include "parser/scansup.h"
 #include "utils/array.h"
 #include "utils/builtins.h"
-#include "utils/pg_locale.h"
 #include "utils/lsyscache.h"
+#include "utils/pg_locale.h"
 
 
 typedef struct varlena unknown;
@@ -186,10 +187,10 @@ byteaout(PG_FUNCTION_ARGS)
 	{
 		if (*vp == '\\')
 			len += 2;
-		else if (isprint((unsigned char) *vp))
-			len++;
-		else
+		else if ((unsigned char) *vp < 0x20 || (unsigned char) *vp > 0x7e)
 			len += 4;
+		else
+			len++;
 	}
 	rp = result = (char *) palloc(len);
 	vp = VARDATA(vlena);
@@ -200,9 +201,7 @@ byteaout(PG_FUNCTION_ARGS)
 			*rp++ = '\\';
 			*rp++ = '\\';
 		}
-		else if (isprint((unsigned char) *vp))
-			*rp++ = *vp;
-		else
+		else if ((unsigned char) *vp < 0x20 || (unsigned char) *vp > 0x7e)
 		{
 			val = *vp;
 			rp[0] = '\\';
@@ -213,6 +212,8 @@ byteaout(PG_FUNCTION_ARGS)
 			rp[1] = DIG(val & 03);
 			rp += 4;
 		}
+		else
+			*rp++ = *vp;
 	}
 	*rp = '\0';
 	PG_RETURN_CSTRING(result);
@@ -259,10 +260,7 @@ textin(PG_FUNCTION_ARGS)
 	text	   *result;
 	int			len;
 
-	/* verify encoding */
 	len = strlen(inputText);
-	pg_verifymbstr(inputText, len, false);
-
 	result = (text *) palloc(len + VARHDRSZ);
 	VARATT_SIZEP(result) = len + VARHDRSZ;
 
@@ -761,9 +759,6 @@ text_position(Datum str, Datum search_str, int matchnum)
 	len1 = (VARSIZE(t1) - VARHDRSZ);
 	len2 = (VARSIZE(t2) - VARHDRSZ);
 
-	/* no use in searching str past point where search_str will fit */
-	px = (len1 - len2);
-
 	if (eml == 1)				/* simple case - single byte encoding */
 	{
 		char	   *p1,
@@ -772,6 +767,9 @@ text_position(Datum str, Datum search_str, int matchnum)
 		p1 = VARDATA(t1);
 		p2 = VARDATA(t2);
 
+		/* no use in searching str past point where search_str will fit */
+		px = (len1 - len2);
+
 		for (p = 0; p <= px; p++)
 		{
 			if ((*p2 == *p1) && (strncmp(p1, p2, len2) == 0))
@@ -799,6 +797,9 @@ text_position(Datum str, Datum search_str, int matchnum)
 		(void) pg_mb2wchar_with_len((unsigned char *) VARDATA(t2), p2, len2);
 		len2 = pg_wchar_strlen(p2);
 
+		/* no use in searching str past point where search_str will fit */
+		px = (len1 - len2);
+
 		for (p = 0; p <= px; p++)
 		{
 			if ((*p2 == *p1) && (pg_wchar_strncmp(p1, p2, len2) == 0))
@@ -864,6 +865,15 @@ varstr_cmp(char *arg1, int len1, char *arg2, int len2)
 
 		result = strcoll(a1p, a2p);
 
+		/*
+		 * In some locales strcoll() can claim that nonidentical strings are
+		 * equal.  Believing that would be bad news for a number of reasons,
+		 * so we follow Perl's lead and sort "equal" strings according to
+		 * strcmp().
+		 */
+		if (result == 0)
+			result = strcmp(a1p, a2p);
+
 		if (len1 >= STACKBUFLEN)
 			pfree(a1p);
 		if (len2 >= STACKBUFLEN)
@@ -916,11 +926,15 @@ texteq(PG_FUNCTION_ARGS)
 	text	   *arg2 = PG_GETARG_TEXT_P(1);
 	bool		result;
 
-	/* fast path for different-length inputs */
+	/*
+	 * Since we only care about equality or not-equality, we can avoid all
+	 * the expense of strcoll() here, and just do bitwise comparison.
+	 */
 	if (VARSIZE(arg1) != VARSIZE(arg2))
 		result = false;
 	else
-		result = (text_cmp(arg1, arg2) == 0);
+		result = (strncmp(VARDATA(arg1), VARDATA(arg2),
+						  VARSIZE(arg1) - VARHDRSZ) == 0);
 
 	PG_FREE_IF_COPY(arg1, 0);
 	PG_FREE_IF_COPY(arg2, 1);
@@ -935,11 +949,15 @@ textne(PG_FUNCTION_ARGS)
 	text	   *arg2 = PG_GETARG_TEXT_P(1);
 	bool		result;
 
-	/* fast path for different-length inputs */
+	/*
+	 * Since we only care about equality or not-equality, we can avoid all
+	 * the expense of strcoll() here, and just do bitwise comparison.
+	 */
 	if (VARSIZE(arg1) != VARSIZE(arg2))
 		result = true;
 	else
-		result = (text_cmp(arg1, arg2) != 0);
+		result = (strncmp(VARDATA(arg1), VARDATA(arg2),
+						  VARSIZE(arg1) - VARHDRSZ) != 0);
 
 	PG_FREE_IF_COPY(arg1, 0);
 	PG_FREE_IF_COPY(arg2, 1);
@@ -1678,7 +1696,6 @@ SplitIdentifierString(char *rawstring, char separator,
 	{
 		char	   *curname;
 		char	   *endp;
-		int			curlen;
 
 		if (*nextp == '\"')
 		{
@@ -1701,21 +1718,30 @@ SplitIdentifierString(char *rawstring, char separator,
 		else
 		{
 			/* Unquoted name --- extends to separator or whitespace */
+			char	   *downname;
+			int			len;
+
 			curname = nextp;
 			while (*nextp && *nextp != separator &&
 				   !isspace((unsigned char) *nextp))
-			{
-				/*
-				 * It's important that this match the identifier
-				 * downcasing code used by backend/parser/scan.l.
-				 */
-				if (isupper((unsigned char) *nextp))
-					*nextp = tolower((unsigned char) *nextp);
 				nextp++;
-			}
 			endp = nextp;
 			if (curname == nextp)
 				return false;	/* empty unquoted name not allowed */
+			/*
+			 * Downcase the identifier, using same code as main lexer does.
+			 *
+			 * XXX because we want to overwrite the input in-place, we cannot
+			 * support a downcasing transformation that increases the
+			 * string length.  This is not a problem given the current
+			 * implementation of downcase_truncate_identifier, but we'll
+			 * probably have to do something about this someday.
+			 */
+			len = endp - curname;
+			downname = downcase_truncate_identifier(curname, len, false);
+			Assert(strlen(downname) <= len);
+			strncpy(curname, downname, len);
+			pfree(downname);
 		}
 
 		while (isspace((unsigned char) *nextp))
@@ -1736,13 +1762,8 @@ SplitIdentifierString(char *rawstring, char separator,
 		/* Now safe to overwrite separator with a null */
 		*endp = '\0';
 
-		/* Truncate name if it's overlength; again, should match scan.l */
-		curlen = strlen(curname);
-		if (curlen >= NAMEDATALEN)
-		{
-			curlen = pg_mbcliplen(curname, curlen, NAMEDATALEN - 1);
-			curname[curlen] = '\0';
-		}
+		/* Truncate name if it's overlength */
+		truncate_identifier(curname, strlen(curname), false);
 
 		/*
 		 * Finished isolating current name --- add it to list
@@ -2230,11 +2251,11 @@ array_to_text(PG_FUNCTION_ARGS)
 Datum
 to_hex32(PG_FUNCTION_ARGS)
 {
-	static char digits[] = "0123456789abcdef";
-	char		buf[32];		/* bigger than needed, but reasonable */
-	char	   *ptr;
+	uint32		value = (uint32) PG_GETARG_INT32(0);
 	text	   *result_text;
-	int32		value = PG_GETARG_INT32(0);
+	char	   *ptr;
+	const char *digits = "0123456789abcdef";
+	char		buf[32];		/* bigger than needed, but reasonable */
 
 	ptr = buf + sizeof(buf) - 1;
 	*ptr = '\0';
@@ -2256,11 +2277,11 @@ to_hex32(PG_FUNCTION_ARGS)
 Datum
 to_hex64(PG_FUNCTION_ARGS)
 {
-	static char digits[] = "0123456789abcdef";
-	char		buf[32];		/* bigger than needed, but reasonable */
-	char	   *ptr;
+	uint64		value = (uint64) PG_GETARG_INT64(0);
 	text	   *result_text;
-	int64		value = PG_GETARG_INT64(0);
+	char	   *ptr;
+	const char *digits = "0123456789abcdef";
+	char		buf[32];		/* bigger than needed, but reasonable */
 
 	ptr = buf + sizeof(buf) - 1;
 	*ptr = '\0';
