@@ -9,10 +9,10 @@
  *		pmod.h							processing modes
  *
  *
- * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $Id: miscadmin.h,v 1.111.2.1 2008/01/03 21:25:58 tgl Exp $
+ * $Id: miscadmin.h,v 1.134 2003/09/24 18:54:01 tgl Exp $
  *
  * NOTES
  *	  some of the information in this file should be moved to
@@ -53,10 +53,10 @@
  *
  * A related, but conceptually distinct, mechanism is the "critical section"
  * mechanism.  A critical section not only holds off cancel/die interrupts,
- * but causes any elog(ERROR) or elog(FATAL) to become elog(STOP) --- that is,
- * a system-wide reset is forced.  Needless to say, only really *critical*
- * code should be marked as a critical section!  Currently, this mechanism
- * is only used for XLOG-related code.
+ * but causes any ereport(ERROR) or ereport(FATAL) to become ereport(PANIC)
+ * --- that is, a system-wide reset is forced.	Needless to say, only really
+ * *critical* code should be marked as a critical section!	Currently, this
+ * mechanism is only used for XLOG-related code.
  *
  *****************************************************************************/
 
@@ -104,8 +104,8 @@ extern void ProcessInterrupts(void);
 /*
  * from postmaster/postmaster.c
  */
-extern bool IsUnderPostmaster;
 extern bool ClientAuthInProgress;
+extern const bool ExecBackend;
 
 extern int	PostmasterMain(int argc, char *argv[]);
 extern void ClosePostmasterPorts(bool pgstat_too);
@@ -113,6 +113,11 @@ extern void ClosePostmasterPorts(bool pgstat_too);
 /*
  * from utils/init/globals.c
  */
+extern bool IsPostmasterEnvironment;
+extern bool IsUnderPostmaster;
+
+extern bool ExitOnAnyError;
+
 extern bool Noversion;
 extern char *DataDir;
 
@@ -130,36 +135,52 @@ extern char pg_pathname[];
  */
 extern DLLIMPORT Oid MyDatabaseId;
 
-/* Date/Time Configuration
+/*
+ * Date/Time Configuration
  *
- * Constants to pass info from runtime environment:
- *	USE_POSTGRES_DATES specifies traditional postgres format for output.
- *	USE_ISO_DATES specifies ISO-compliant format for output.
- *	USE_SQL_DATES specified Oracle/Ingres-compliant format for output.
- *	USE_GERMAN_DATES specifies German-style dd.mm/yyyy date format.
+ * DateStyle defines the output formatting choice for date/time types:
+ *	USE_POSTGRES_DATES specifies traditional Postgres format
+ *	USE_ISO_DATES specifies ISO-compliant format
+ *	USE_SQL_DATES specifies Oracle/Ingres-compliant format
+ *	USE_GERMAN_DATES specifies German-style dd.mm/yyyy
  *
- * DateStyle specifies preference for date formatting for output.
- * EuroDates if client prefers dates interpreted and written w/European conventions.
+ * DateOrder defines the field order to be assumed when reading an
+ * ambiguous date (anything not in YYYY-MM-DD format, with a four-digit
+ * year field first, is taken to be ambiguous):
+ *	DATEORDER_YMD specifies field order yy-mm-dd
+ *	DATEORDER_DMY specifies field order dd-mm-yy ("European" convention)
+ *	DATEORDER_MDY specifies field order mm-dd-yy ("US" convention)
  *
- * HasCTZSet if client timezone is specified by client.
- * CDayLight is the apparent daylight savings time status.
- * CTimeZone is the timezone offset in seconds.
- * CTZName is the timezone label.
+ * In the Postgres and SQL DateStyles, DateOrder also selects output field
+ * order: day comes before month in DMY style, else month comes before day.
+ *
+ * The user-visible "DateStyle" run-time parameter subsumes both of these.
  */
 
-#define MAXTZLEN		10		/* max TZ name len, not counting tr. null */
-
+/* valid DateStyle values */
 #define USE_POSTGRES_DATES		0
 #define USE_ISO_DATES			1
 #define USE_SQL_DATES			2
 #define USE_GERMAN_DATES		3
 
+/* valid DateOrder values */
+#define DATEORDER_YMD			0
+#define DATEORDER_DMY			1
+#define DATEORDER_MDY			2
+
 extern int	DateStyle;
-extern bool EuroDates;
+extern int	DateOrder;
+
+/*
+ * HasCTZSet is true if user has set timezone as a numeric offset from UTC.
+ * If so, CTimeZone is the timezone offset in seconds (using the Unix-ish
+ * sign convention, ie, positive offset is west of UTC, rather than the
+ * SQL-ish convention that positive is east of UTC).
+ */
 extern bool HasCTZSet;
-extern bool CDayLight;
 extern int	CTimeZone;
-extern char CTZName[];
+
+#define MAXTZLEN		10		/* max TZ name len, not counting tr. null */
 
 extern bool enableFsync;
 extern bool allowSystemTableMods;
@@ -170,13 +191,12 @@ extern int	VacuumMem;
  *	A few postmaster startup options are exported here so the
  *	configuration file processor can access them.
  */
-
 extern bool NetServer;
 extern bool EnableSSL;
 extern bool SilentMode;
 extern int	MaxBackends;
 extern int	ReservedBackends;
-extern int	NBuffers;
+extern DLLIMPORT int NBuffers;
 extern int	PostPortNumber;
 extern int	Unix_socket_permissions;
 extern char *Unix_socket_group;
@@ -189,7 +209,6 @@ extern char *VirtualHost;
  *			POSTGRES directory path definitions.							 *
  *****************************************************************************/
 
-extern char *DatabaseName;
 extern char *DatabasePath;
 
 /* in utils/misc/database.c */
@@ -197,19 +216,16 @@ extern void GetRawDatabaseInfo(const char *name, Oid *db_id, char *path);
 extern char *ExpandDatabasePath(const char *path);
 
 /* now in utils/init/miscinit.c */
-extern void SetDatabaseName(const char *name);
 extern void SetDatabasePath(const char *path);
 
-extern char *GetUserNameFromId(Oid userid);
-
-extern Oid	GetUserId(void);
-extern Oid	GetSessionUserId(void);
-extern void GetUserIdAndContext(Oid *userid, bool *sec_def_context);
-extern void SetUserIdAndContext(Oid userid, bool sec_def_context);
-extern bool InSecurityDefinerContext(void);
+extern char *GetUserNameFromId(AclId userid);
+extern AclId GetUserId(void);
+extern void SetUserId(AclId userid);
+extern AclId GetSessionUserId(void);
+extern void SetSessionUserId(AclId userid);
 extern void InitializeSessionUserId(const char *username);
 extern void InitializeSessionUserIdStandalone(void);
-extern void SetSessionAuthorization(Oid userid);
+extern void SetSessionAuthorization(AclId userid, bool is_superuser);
 
 extern void SetDataDir(const char *dir);
 
@@ -217,16 +233,9 @@ extern int FindExec(char *full_path, const char *argv0,
 		 const char *binary_name);
 extern int	CheckPathAccess(char *path, char *name, int open_mode);
 
-#ifdef CYR_RECODE
-extern void SetCharSet(void);
-extern char *convertstr(unsigned char *buff, int len, int dest);
-#endif
-
 /* in utils/misc/superuser.c */
 extern bool superuser(void);	/* current user is superuser */
-extern bool superuser_arg(Oid userid);	/* given user is superuser */
-extern bool is_dbadmin(Oid dbid);		/* current user is owner of
-										 * database */
+extern bool superuser_arg(AclId userid);		/* given user is superuser */
 
 
 /*****************************************************************************
@@ -287,17 +296,17 @@ extern void InitPostgres(const char *dbname, const char *username);
 extern void BaseInit(void);
 
 /* in utils/init/miscinit.c */
-extern bool CreateDataDirLockFile(const char *datadir, bool amPostmaster);
-extern bool CreateSocketLockFile(const char *socketfile, bool amPostmaster);
+extern void IgnoreSystemIndexes(bool mode);
+extern bool IsIgnoringSystemIndexes(void);
+extern void SetReindexProcessing(Oid heapOid, Oid indexOid);
+extern bool ReindexIsProcessingHeap(Oid heapOid);
+extern bool ReindexIsProcessingIndex(Oid indexOid);
+extern void CreateDataDirLockFile(const char *datadir, bool amPostmaster);
+extern void CreateSocketLockFile(const char *socketfile, bool amPostmaster);
 extern void TouchSocketLockFile(void);
 extern void RecordSharedMemoryInLockFile(unsigned long id1,
 							 unsigned long id2);
-
 extern void ValidatePgVersion(const char *path);
-
-/* these externs do not belong here... */
-extern void IgnoreSystemIndexes(bool mode);
-extern bool IsIgnoringSystemIndexes(void);
-extern bool IsCacheInitialized(void);
+extern void process_preload_libraries(char *preload_libraries_string);
 
 #endif   /* MISCADMIN_H */
